@@ -240,6 +240,10 @@ func (a *App) Template(c TemplateConfigProvider) error {
 		// Live output should never be enabled for the "template" subcommand to avoid breaking `helmfile template | kubectl apply -f -`
 		run.helm.SetEnableLiveOutput(false)
 
+		// Reset helm extra args to not pollute BuildDeps() and AddRepo() on subsequent helmfiles
+		// https://github.com/helmfile/helmfile/issues/1749
+		run.helm.SetExtraArgs()
+
 		prepErr := run.withPreparedCharts("template", state.ChartPrepareOptions{
 			SkipRepos:              c.SkipRefresh() || c.SkipDeps(),
 			SkipRefresh:            c.SkipRefresh(),
@@ -381,6 +385,7 @@ func (a *App) Sync(c SyncConfigProvider) error {
 			SkipRefresh:            c.SkipRefresh(),
 			SkipDeps:               c.SkipDeps(),
 			Wait:                   c.Wait(),
+			WaitRetries:            c.WaitRetries(),
 			WaitForJobs:            c.WaitForJobs(),
 			IncludeCRDs:            &includeCRDs,
 			IncludeTransitiveNeeds: c.IncludeNeeds(),
@@ -415,6 +420,7 @@ func (a *App) Apply(c ApplyConfigProvider) error {
 			SkipRefresh:            c.SkipRefresh(),
 			SkipDeps:               c.SkipDeps(),
 			Wait:                   c.Wait(),
+			WaitRetries:            c.WaitRetries(),
 			WaitForJobs:            c.WaitForJobs(),
 			IncludeCRDs:            &includeCRDs,
 			SkipCleanup:            c.RetainValuesFiles() || c.SkipCleanup(),
@@ -1542,6 +1548,7 @@ Do you really want to apply?
 					SkipCleanup:          c.RetainValuesFiles() || c.SkipCleanup(),
 					SkipCRDs:             c.SkipCRDs(),
 					Wait:                 c.Wait(),
+					WaitRetries:          c.WaitRetries(),
 					WaitForJobs:          c.WaitForJobs(),
 					ReuseValues:          c.ReuseValues(),
 					ResetValues:          c.ResetValues(),
@@ -1550,6 +1557,7 @@ Do you really want to apply?
 					SkipSchemaValidation: c.SkipSchemaValidation(),
 					SyncArgs:             c.SyncArgs(),
 					HideNotes:            c.HideNotes(),
+					TakeOwnership:        c.TakeOwnership(),
 				}
 				return subst.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency(), syncOpts)
 			}))
@@ -1938,6 +1946,7 @@ Do you really want to sync?
 					Set:              c.Set(),
 					SkipCRDs:         c.SkipCRDs(),
 					Wait:             c.Wait(),
+					WaitRetries:      c.WaitRetries(),
 					WaitForJobs:      c.WaitForJobs(),
 					ReuseValues:      c.ReuseValues(),
 					ResetValues:      c.ResetValues(),
@@ -1945,6 +1954,7 @@ Do you really want to sync?
 					PostRendererArgs: c.PostRendererArgs(),
 					SyncArgs:         c.SyncArgs(),
 					HideNotes:        c.HideNotes(),
+					TakeOwnership:    c.TakeOwnership(),
 				}
 				return subst.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency(), opts)
 			}))
@@ -1974,6 +1984,7 @@ func (a *App) template(r *Run, c TemplateConfigProvider) (bool, []error) {
 		opts := &state.TemplateOpts{
 			Set:               c.Set(),
 			IncludeCRDs:       c.IncludeCRDs(),
+			NoHooks:           c.NoHooks(),
 			OutputDirTemplate: c.OutputDirTemplate(),
 			SkipCleanup:       c.SkipCleanup(),
 			SkipTests:         c.SkipTests(),
