@@ -54,6 +54,7 @@ type ApplyConfigProvider interface {
 	SkipSchemaValidation() bool
 	Cascade() string
 	HideNotes() bool
+	TakeOwnership() bool
 	SuppressOutputLineRegex() []string
 
 	Values() []string
@@ -62,6 +63,7 @@ type ApplyConfigProvider interface {
 	SkipDeps() bool
 	SkipRefresh() bool
 	Wait() bool
+	WaitRetries() int
 	WaitForJobs() bool
 
 	IncludeTests() bool
@@ -103,6 +105,7 @@ type SyncConfigProvider interface {
 	PostRenderer() string
 	PostRendererArgs() []string
 	HideNotes() bool
+	TakeOwnership() bool
 	Cascade() string
 
 	Values() []string
@@ -111,6 +114,7 @@ type SyncConfigProvider interface {
 	SkipDeps() bool
 	SkipRefresh() bool
 	Wait() bool
+	WaitRetries() int
 	WaitForJobs() bool
 	SyncArgs() string
 
@@ -246,6 +250,7 @@ type TemplateConfigProvider interface {
 	SkipTests() bool
 	OutputDir() string
 	IncludeCRDs() bool
+	NoHooks() bool
 	KubeVersion() string
 	ShowOnly() []string
 
