@@ -48,6 +48,7 @@ type DiffOptions struct {
 	DiffArgs string
 	// SuppressOutputLineRegex is a list of regexes to suppress output lines
 	SuppressOutputLineRegex []string
+	SkipSchemaValidation    bool
 }
 
 // NewDiffOptions creates a new Apply
@@ -199,3 +200,7 @@ func (t *DiffImpl) PostRendererArgs() []string {
 func (t *DiffImpl) SuppressOutputLineRegex() []string {
 	return t.DiffOptions.SuppressOutputLineRegex
 }
+
+func (t *DiffImpl) SkipSchemaValidation() bool {
+	return t.DiffOptions.SkipSchemaValidation
+}
