@@ -76,13 +76,16 @@ func TestAppendWaitFlags(t *testing.T) {
 		name     string
 		release  *ReleaseSpec
 		syncOpts *SyncOpts
+		helm     helmexec.Interface
 		helmSpec HelmSpec
 		expected []string
 	}{
+		// --wait
 		{
 			name:     "release wait",
 			release:  &ReleaseSpec{Wait: &[]bool{true}[0]},
 			syncOpts: nil,
+			helm:     testutil.NewVersionHelmExec("3.11.0"),
 			helmSpec: HelmSpec{},
 			expected: []string{"--wait"},
 		},
@@ -90,6 +93,7 @@ func TestAppendWaitFlags(t *testing.T) {
 			name:     "cli flags wait",
 			release:  &ReleaseSpec{},
 			syncOpts: &SyncOpts{Wait: true},
+			helm:     testutil.NewVersionHelmExec("3.11.0"),
 			helmSpec: HelmSpec{},
 			expected: []string{"--wait"},
 		},
@@ -97,6 +101,7 @@ func TestAppendWaitFlags(t *testing.T) {
 			name:     "helm defaults wait",
 			release:  &ReleaseSpec{},
 			syncOpts: nil,
+			helm:     testutil.NewVersionHelmExec("3.11.0"),
 			helmSpec: HelmSpec{Wait: true},
 			expected: []string{"--wait"},
 		},
@@ -104,6 +109,7 @@ func TestAppendWaitFlags(t *testing.T) {
 			name:     "release wait false",
 			release:  &ReleaseSpec{Wait: &[]bool{false}[0]},
 			syncOpts: nil,
+			helm:     testutil.NewVersionHelmExec("3.11.0"),
 			helmSpec: HelmSpec{Wait: true},
 			expected: []string{},
 		},
@@ -111,6 +117,7 @@ func TestAppendWaitFlags(t *testing.T) {
 			name:     "cli flags wait false",
 			release:  &ReleaseSpec{},
 			syncOpts: &SyncOpts{},
+			helm:     testutil.NewVersionHelmExec("3.11.0"),
 			helmSpec: HelmSpec{Wait: true},
 			expected: []string{"--wait"},
 		},
@@ -118,16 +125,74 @@ func TestAppendWaitFlags(t *testing.T) {
 			name:     "helm defaults wait false",
 			release:  &ReleaseSpec{},
 			syncOpts: nil,
+			helm:     testutil.NewVersionHelmExec("3.11.0"),
 			helmSpec: HelmSpec{Wait: false},
 			expected: []string{},
 		},
+		// --wait-retries
+		{
+			name:     "release wait and retry unsupported",
+			release:  &ReleaseSpec{Wait: &[]bool{true}[0], WaitRetries: &[]int{1}[0]},
+			syncOpts: nil,
+			helm:     testutil.NewVersionHelmExec("3.11.0"),
+			helmSpec: HelmSpec{},
+			expected: []string{"--wait"},
+		},
+		{
+			name:     "release wait and retry supported",
+			release:  &ReleaseSpec{Wait: &[]bool{true}[0], WaitRetries: &[]int{1}[0]},
+			syncOpts: nil,
+			helm:     testutil.NewVersionHelmExec("3.15.0"),
+			helmSpec: HelmSpec{},
+			expected: []string{"--wait", "--wait-retries", "1"},
+		},
+		{
+			name:     "no wait retry",
+			release:  &ReleaseSpec{WaitRetries: &[]int{1}[0]},
+			syncOpts: nil,
+			helm:     testutil.NewVersionHelmExec("3.15.0"),
+			helmSpec: HelmSpec{},
+			expected: []string{},
+		},
+		{
+			name:     "cli flags wait and retry",
+			release:  &ReleaseSpec{},
+			syncOpts: &SyncOpts{Wait: true, WaitRetries: 2},
+			helm:     testutil.NewVersionHelmExec("3.15.0"),
+			helmSpec: HelmSpec{},
+			expected: []string{"--wait", "--wait-retries", "2"},
+		},
+		{
+			name:     "helm defaults wait retry",
+			release:  &ReleaseSpec{},
+			syncOpts: nil,
+			helm:     testutil.NewVersionHelmExec("3.15.0"),
+			helmSpec: HelmSpec{Wait: true, WaitRetries: 3},
+			expected: []string{"--wait", "--wait-retries", "3"},
+		},
+		{
+			name:     "release wait default retries",
+			release:  &ReleaseSpec{Wait: &[]bool{true}[0]},
+			syncOpts: nil,
+			helm:     testutil.NewVersionHelmExec("3.15.0"),
+			helmSpec: HelmSpec{WaitRetries: 4},
+			expected: []string{"--wait", "--wait-retries", "4"},
+		},
+		{
+			name:     "release retries default wait",
+			release:  &ReleaseSpec{WaitRetries: &[]int{5}[0]},
+			syncOpts: nil,
+			helm:     testutil.NewVersionHelmExec("3.15.0"),
+			helmSpec: HelmSpec{Wait: true},
+			expected: []string{"--wait", "--wait-retries", "5"},
+		},
 	}
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			st := &HelmState{}
 			st.HelmDefaults = tt.helmSpec
-			got := st.appendWaitFlags([]string{}, tt.release, tt.syncOpts)
+			got := st.appendWaitFlags([]string{}, tt.helm, tt.release, tt.syncOpts)
 			require.Equalf(t, tt.expected, got, "appendWaitFlags() = %v, want %v", got, tt.expected)
 		})
 	}
@@ -321,3 +386,48 @@ func TestAppendHideNotesFlags(t *testing.T) {
 		})
 	}
 }
+
+func TestAppendTakeOwnershipFlags(t *testing.T) {
+	type args struct {
+		flags    []string
+		helm     helmexec.Interface
+		helmSpec HelmSpec
+		opt      *SyncOpts
+		expected []string
+	}
+	tests := []struct {
+		name string
+		args args
+	}{
+		{
+			name: "no take-ownership when helm less than 3.17.0",
+			args: args{
+				flags: []string{},
+				helm:  testutil.NewVersionHelmExec("3.16.0"),
+				opt: &SyncOpts{
+					TakeOwnership: true,
+				},
+				expected: []string{},
+			},
+		},
+		{
+			name: "take-ownership from cmd flag",
+			args: args{
+				flags: []string{},
+				helm:  testutil.NewVersionHelmExec("3.17.0"),
+				opt: &SyncOpts{
+					TakeOwnership: true,
+				},
+				expected: []string{"--take-ownership"},
+			},
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			st := &HelmState{}
+			st.HelmDefaults = tt.args.helmSpec
+			got := st.appendTakeOwnershipFlags(tt.args.flags, tt.args.helm, tt.args.opt)
+			require.Equalf(t, tt.args.expected, got, "appendTakeOwnershipFlags() = %v, want %v", got, tt.args.expected)
+		})
+	}
+}
