@@ -27,7 +27,8 @@ export HELM_DATA_HOME="${helm_dir}/data"
 export HELM_HOME="${HELM_DATA_HOME}"
 export HELM_PLUGINS="${HELM_DATA_HOME}/plugins"
 export HELM_CONFIG_HOME="${helm_dir}/config"
-HELM_DIFF_VERSION="${HELM_DIFF_VERSION:-3.9.12}"
+HELM_DIFF_VERSION="${HELM_DIFF_VERSION:-3.9.14}"
+HELM_GIT_VERSION="${HELM_GIT_VERSION:-1.3.0}"
 HELM_SECRETS_VERSION="${HELM_SECRETS_VERSION:-3.15.0}"
 export GNUPGHOME="${PWD}/${dir}/.gnupg"
 export SOPS_PGP_FP="B2D6D7BBEC03B2E66571C8C00AD18E16CFDEF700"
@@ -70,7 +71,8 @@ set -e
 trap cleanup EXIT
 info "Using namespace: ${test_ns}"
 info "Using Helm version:" $(${helm} version --short | grep -o 'v[0-9.]\+')
-${helm} plugin ls | grep diff || ${helm} plugin install https://github.com/databus23/helm-diff --version v${HELM_DIFF_VERSION}
+${helm} plugin ls | grep "^diff" || ${helm} plugin install https://github.com/databus23/helm-diff --version v${HELM_DIFF_VERSION}
+${helm} plugin ls | grep "^helm-git" || ${helm} plugin install https://github.com/aslafy-z/helm-git --version v${HELM_GIT_VERSION}
 info "Using Kustomize version: $(kustomize version --short | grep -o 'v[0-9.]\+')"
 ${kubectl} get namespace ${test_ns} &> /dev/null && warn "Namespace ${test_ns} exists, from a previous test run?"
 ${kubectl} create namespace ${test_ns} || fail "Could not create namespace ${test_ns}"
@@ -98,6 +100,7 @@ ${kubectl} create namespace ${test_ns} || fail "Could not create namespace ${tes
 . ${dir}/test-cases/deps-kustomization-i-1402.sh
 . ${dir}/test-cases/hcl-secrets.sh
 . ${dir}/test-cases/issue-1749.sh
+. ${dir}/test-cases/issue-1893.sh
 
 # ALL DONE -----------------------------------------------------------------------------------------------------------
 
